gchecky.model.tracking_data_t

Package gchecky :: Module model :: Class tracking_data_t |
[hide private]
[frames] | no frames]

# Class tracking_data_t

source code

    object --+
             |
     gxml.Node --+
                 |
                tracking_data_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| carrier = `String:PATH(carrier):REQ:EMPTY:VALS("DHL","FedEx","U`...``
| tracking_number = `String:PATH(tracking-number):REQ:EMPTY`
| _fields = ``{``'``carrier``'``:` String:PATH(carrier):REQ:EMPTY:VALS("DHL`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### carrier Value:
      String:PATH(carrier):REQ:EMPTY:VALS("DHL","FedEx","UPS","USPS","Other"
      )

  ### _fields list of meta-Fields of this class. Value:
      {'carrier': String:PATH(carrier):REQ:EMPTY:VALS("DHL","FedEx","UPS","U
      SPS","Other"),
       'tracking_number': String:PATH(tracking-number):REQ:EMPTY}